@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2005 Ross Burton, 2011-2013 Andreas Rönnquist
+ *	Copyright (C) 2005 Ross Burton, 2011-2015 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -53,9 +53,9 @@ static gboolean emulate = FALSE;
 static gboolean show_version = FALSE;
 
 #ifdef HAVE_GTK3
-	// libwnck Version Information is only availible if you have
-	// libwnck 3.0 or later
-	static gboolean show_wnck_version = FALSE;
+// libwnck Version Information is only availible if you have
+// libwnck 3.0 or later
+static gboolean show_wnck_version = FALSE;
 #endif
 
 static gchar *script_folder = NULL;
@@ -69,7 +69,7 @@ gchar *config_filename = NULL;
  *
  */
 static void load_list_of_scripts(WnckScreen *screen, WnckWindow *window,
-											GSList *file_list)
+                                 GSList *file_list)
 {
 	GSList *temp_file_list = file_list;
 	// set the window to work on
@@ -82,7 +82,7 @@ static void load_list_of_scripts(WnckScreen *screen, WnckWindow *window,
 			gchar *filename = (gchar*)temp_file_list->data;
 
 			// is it a LUA file?
-			if (g_str_has_suffix((gchar*)filename,".lua")) {
+			if (g_str_has_suffix((gchar*)filename, ".lua")) {
 
 				// init the script, run it
 				if (!load_script(global_lua_state, filename)) {
@@ -135,9 +135,9 @@ void init_screens()
 		WnckScreen *screen = wnck_screen_get(i);
 
 		g_signal_connect(screen, "window-opened",
-								(GCallback)window_opened_cb, NULL);
+		                 (GCallback)window_opened_cb, NULL);
 		g_signal_connect(screen, "window-closed",
-								(GCallback)window_closed_cb, NULL);
+		                 (GCallback)window_closed_cb, NULL);
 	}
 }
 
@@ -215,7 +215,7 @@ void print_script_lists()
 	// If we are running debug mode - print the list of files:
 	if (debug) {
 		printf(_("List of LUA files handling \"%s\" events in folder:"),
-			"window_open");
+		       "window_open");
 		printf("\n");
 		if (file_window_open_list)
 			print_list(file_window_open_list);
@@ -223,7 +223,7 @@ void print_script_lists()
 
 	if (debug) {
 		printf(_("List of LUA files handling \"%s\" events in folder:"),
-			"window_close");
+		       "window_close");
 		printf("\n");
 		if (file_window_close_list)
 			print_list(file_window_close_list);
@@ -235,16 +235,16 @@ void print_script_lists()
  *
  */
 void folder_changed_callback(GFileMonitor *mon,
-										GFile *first_file,
-										GFile *second_file,
-										GFileMonitorEvent event,
-										gpointer user_data)
+                             GFile *first_file,
+                             GFile *second_file,
+                             GFileMonitorEvent event,
+                             gpointer user_data)
 {
 	gchar *our_filename = (gchar*)(user_data);
 
 	// If a file is created or deleted, we need to check the file lists again
 	if ((event == G_FILE_MONITOR_EVENT_CREATED) ||
-		 (event == G_FILE_MONITOR_EVENT_DELETED)) {
+	        (event == G_FILE_MONITOR_EVENT_DELETED)) {
 
 		clear_file_lists();
 
@@ -288,20 +288,25 @@ void folder_changed_callback(GFileMonitor *mon,
  */
 int main(int argc, char *argv[])
 {
-	static const GOptionEntry options[]={
-		{ "debug",			'd',	0,	G_OPTION_ARG_NONE,		&debug,
-			N_("Print debug info to stdout")},
-		{ "emulate",		'e',	0,	G_OPTION_ARG_NONE,		&emulate,
-			N_("Don't apply any rules, only emulate execution")},
-		{ "folder",			'f',	0,	G_OPTION_ARG_STRING,		&script_folder,
-			N_("Search for scripts in this folder"),N_("FOLDER")},
-		{ "version",		'v',	0,	G_OPTION_ARG_NONE,		&show_version,
-			N_("Show Devilspie2 version and quit")},
+	static const GOptionEntry options[]= {
+		{	"debug",			'd',	0,	G_OPTION_ARG_NONE,		&debug,
+			N_("Print debug info to stdout")
+		},
+		{	"emulate",		'e',	0,	G_OPTION_ARG_NONE,		&emulate,
+			N_("Don't apply any rules, only emulate execution")
+		},
+		{	"folder",			'f',	0,	G_OPTION_ARG_STRING,		&script_folder,
+			N_("Search for scripts in this folder"),N_("FOLDER")
+		},
+		{	"version",		'v',	0,	G_OPTION_ARG_NONE,		&show_version,
+			N_("Show Devilspie2 version and quit")
+		},
 #ifdef HAVE_GTK3
 		// libwnck Version Information is only availible if you have
 		// libwnck 3.0 or later
-		{ "wnck-version",	'w',	0,	G_OPTION_ARG_NONE,		&show_wnck_version,
-			N_("Show libwnck version and quit")},
+		{	"wnck-version",	'w',	0,	G_OPTION_ARG_NONE,		&show_wnck_version,
+			N_("Show libwnck version and quit")
+		},
 #endif
 		{ NULL }
 	};
@@ -319,7 +324,7 @@ int main(int argc, char *argv[])
 	gdk_init(&argc, &argv);
 
 	gchar *devilspie2_description =
-		g_strdup_printf(_("apply rules on windows"));
+	    g_strdup_printf(_("apply rules on windows"));
 
 	gchar *full_desc_string = g_strdup_printf("- %s", devilspie2_description);
 
@@ -338,9 +343,9 @@ int main(int argc, char *argv[])
 	if (script_folder == NULL) {
 
 		temp_folder = g_build_path(G_DIR_SEPARATOR_S,
-										g_get_user_config_dir(),
-										"devilspie2",
-										NULL);
+		                           g_get_user_config_dir(),
+		                           "devilspie2",
+		                           NULL);
 
 		// check if the folder does exist
 		if (!g_file_test(temp_folder, G_FILE_TEST_IS_DIR)) {
@@ -392,9 +397,9 @@ int main(int argc, char *argv[])
 	set_current_window(NULL);
 
 	config_filename =
-		g_build_filename(script_folder, "devilspie2.lua", NULL);
+	    g_build_filename(script_folder, "devilspie2.lua", NULL);
 
-	if (load_config(config_filename)!=0) {
+	if (load_config(config_filename) != 0) {
 
 		devilspie_exit();
 		return EXIT_FAILURE;
@@ -424,7 +429,7 @@ int main(int argc, char *argv[])
 	directory_file = g_file_new_for_path(script_folder);
 //	mon = g_file_monitor_directory(directory_file, G_FILE_MONITOR_WATCH_MOUNTS,
 	mon = g_file_monitor_directory(directory_file, G_FILE_MONITOR_NONE,
-												NULL, NULL);
+	                               NULL, NULL);
 	if (!mon) {
 		printf("%s", _("Couldn't create directory monitor!"));
 		printf("\n");
@@ -432,7 +437,7 @@ int main(int argc, char *argv[])
 	}
 
 	g_signal_connect(mon, "changed", G_CALLBACK(folder_changed_callback),
-		(gpointer)(config_filename));
+	                 (gpointer)(config_filename));
 
 	global_lua_state = init_script();
 	print_script_lists();
