@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2014 Andreas Rönnquist
+ *	Copyright (C) 2011-2015 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -132,12 +132,14 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "get_window_is_maximized", c_get_window_is_maximized);
 
 	lua_register(lua, "get_window_is_maximized_vertically",
-		c_get_window_is_maximized_vertically);
+	             c_get_window_is_maximized_vertically);
 
 	lua_register(lua, "get_window_is_maximized_horisontally",
-		c_get_window_is_maximized_horisontally);
+	             c_get_window_is_maximized_horisontally);
 	lua_register(lua, "get_window_is_maximized_horizontally",
-		c_get_window_is_maximized_horisontally);
+	             c_get_window_is_maximized_horisontally);
+	lua_register(lua, "get_window_is_pinned",
+	             c_get_window_is_pinned);
 
 	lua_register(lua, "set_window_below", c_set_window_below);
 	lua_register(lua, "set_window_above", c_set_window_above);
@@ -193,7 +195,7 @@ load_script(lua_State *lua,char *filename)
 		} else {
 
 			// We got an error, print it
-			printf("%s\n",lua_tostring(lua, -1));
+			printf("%s\n", lua_tostring(lua, -1));
 
 			lua_pop(lua, 1);
 
