@@ -1,6 +1,6 @@
 /**
  *	This file is part of devilspie2
- *	Copyright (C) 2011-2014 Andreas Rönnquist
+ *	Copyright (C) 2011-2015 Andreas Rönnquist
  *
  *	devilspie2 is free software: you can redistribute it and/or
  *	modify it under the terms of the GNU General Public License as published
@@ -136,9 +136,9 @@ int c_set_window_geometry(lua_State *lua)
 	int type4 = lua_type(lua, 4);
 
 	if ((type1 != LUA_TNUMBER) ||
-	    (type2 != LUA_TNUMBER) ||
-	    (type3 != LUA_TNUMBER) ||
-	    (type4 != LUA_TNUMBER)) {
+	        (type2 != LUA_TNUMBER) ||
+	        (type3 != LUA_TNUMBER) ||
+	        (type4 != LUA_TNUMBER)) {
 		luaL_error(lua, "set_window_geometry: %s", four_indata_expected_error);
 		return 0;
 	}
@@ -167,7 +167,7 @@ int c_set_window_geometry2(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 4) {
-		luaL_error(lua,"set_window_geometry: %s",four_indata_expected_error);
+		luaL_error(lua,"set_window_geometry: %s", four_indata_expected_error);
 		return 0;
 	}
 
@@ -177,9 +177,9 @@ int c_set_window_geometry2(lua_State *lua)
 	int type4 = lua_type(lua, 4);
 
 	if ((type1 != LUA_TNUMBER) ||
-	    (type2 != LUA_TNUMBER) ||
-	    (type3 != LUA_TNUMBER) ||
-	    (type4 != LUA_TNUMBER)) {
+	        (type2 != LUA_TNUMBER) ||
+	        (type3 != LUA_TNUMBER) ||
+	        (type4 != LUA_TNUMBER)) {
 		luaL_error(lua, "set_window_geometry: %s", four_indata_expected_error);
 		return 0;
 	}
@@ -195,8 +195,8 @@ int c_set_window_geometry2(lua_State *lua)
 		if (window) {
 			XMoveResizeWindow(gdk_x11_get_default_xdisplay(),
 			                  wnck_window_get_xid(window),
-			                  x,y,
-			                  xsize,ysize);
+			                  x, y,
+			                  xsize, ysize);
 		}
 	}
 
@@ -233,9 +233,9 @@ int c_set_window_position(lua_State *lua)
 
 		if (window) {
 			wnck_window_set_geometry(window,
-				WNCK_WINDOW_GRAVITY_CURRENT,
-				WNCK_WINDOW_CHANGE_X + WNCK_WINDOW_CHANGE_Y,
-				x, y, -1, -1);
+			                         WNCK_WINDOW_GRAVITY_CURRENT,
+			                         WNCK_WINDOW_CHANGE_X + WNCK_WINDOW_CHANGE_Y,
+			                         x, y, -1, -1);
 		}
 	}
 
@@ -255,8 +255,8 @@ int c_set_window_position2(lua_State *lua)
 		return 0;
 	}
 
-	int type1 = lua_type(lua,1);
-	int type2 = lua_type(lua,2);
+	int type1 = lua_type(lua, 1);
+	int type2 = lua_type(lua, 2);
 
 	if ((type1 != LUA_TNUMBER) || (type2 != LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_position2: %s", two_indata_expected_error);
@@ -273,7 +273,7 @@ int c_set_window_position2(lua_State *lua)
 		if (window) {
 			XMoveWindow(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()),
 			            wnck_window_get_xid(window),
-			            x,y);
+			            x, y);
 		}
 	}
 
@@ -293,8 +293,8 @@ int c_set_window_size(lua_State *lua)
 		return 0;
 	}
 
-	int type1 = lua_type(lua,1);
-	int type2 = lua_type(lua,2);
+	int type1 = lua_type(lua, 1);
+	int type2 = lua_type(lua, 2);
 
 	if ((type1 != LUA_TNUMBER) || (type2 != LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_size: %s", two_indata_expected_error);
@@ -312,13 +312,13 @@ int c_set_window_size(lua_State *lua)
 
 			devilspie2_error_trap_push();
 			wnck_window_set_geometry(window,
-				WNCK_WINDOW_GRAVITY_CURRENT,
-				WNCK_WINDOW_CHANGE_WIDTH + WNCK_WINDOW_CHANGE_HEIGHT,
-				-1, -1, x, y);
+			                         WNCK_WINDOW_GRAVITY_CURRENT,
+			                         WNCK_WINDOW_CHANGE_WIDTH + WNCK_WINDOW_CHANGE_HEIGHT,
+			                         -1, -1, x, y);
 
 			if (devilspie2_error_trap_pop()) {
 				gchar *temperror=
-					g_strdup_printf("set_window_size: %s", failed_string);
+				    g_strdup_printf("set_window_size: %s", failed_string);
 				g_printerr("%s", temperror);
 
 				g_free(temperror);
@@ -342,11 +342,11 @@ int c_set_window_strut(lua_State *lua)
 	}
 
 	if (!devilspie2_emulate) {
-		#if __x86_64__
+#if __x86_64__
 		int64_t struts[12];
-		#else
+#else
 		int32_t struts[12];
-		#endif
+#endif
 		int i;
 		for (i = 0; i < 12; i++) {
 			struts[i] = i < top ? lua_tonumber(lua, i + 1) : 0;
@@ -357,12 +357,12 @@ int c_set_window_strut(lua_State *lua)
 
 		if (window) {
 			XChangeProperty(dpy,
-							wnck_window_get_xid(window),
-							XInternAtom(dpy, "_NET_WM_STRUT_PARTIAL", False), XA_CARDINAL,
-							32,
-							PropModeReplace,
-							(unsigned char*)struts,
-							12);
+			                wnck_window_get_xid(window),
+			                XInternAtom(dpy, "_NET_WM_STRUT_PARTIAL", False), XA_CARDINAL,
+			                32,
+			                PropModeReplace,
+			                (unsigned char*)struts,
+			                12);
 			XSync(dpy, False);
 		}
 	}
@@ -439,7 +439,7 @@ int c_get_application_name(lua_State *lua)
 	if (window) {
 
 		WnckApplication *application=
-			wnck_window_get_application(get_current_window());
+		    wnck_window_get_application(get_current_window());
 		application_name = wnck_application_get_name(application);
 
 	} else {
@@ -471,14 +471,17 @@ int c_debug_print(lua_State *lua)
 		s = lua_tostring(lua, -1);  /* get result */
 		if (s == NULL)
 			return luaL_error(lua, LUA_QL("tostring") " must return a string to "
-									LUA_QL("print"));
+			                  LUA_QL("print"));
 		if (i > 1) {
 			if (devilspie2_debug) fputs("\t", stdout);
 		}
 		if (devilspie2_debug) fputs(s, stdout);
 		lua_pop(lua, 1);  /* pop result */
 	}
-	if (devilspie2_debug) fputs("\n", stdout);
+	if (devilspie2_debug) {
+		fputs("\n", stdout);
+		fflush(stdout);
+	}
 
 	return 0;
 }
@@ -547,7 +550,7 @@ int c_minimize_window(lua_State *lua)
 	}
 
 	if (!devilspie2_emulate) {
-				WnckWindow *window = get_current_window();
+		WnckWindow *window = get_current_window();
 
 		if (window) {
 
@@ -687,7 +690,7 @@ int c_set_window_workspace(lua_State *lua)
 
 	if (type!=LUA_TNUMBER) {
 		luaL_error(lua, "set_window_workspace: %s",
-			number_expected_as_indata_error);
+		           number_expected_as_indata_error);
 		return 0;
 	}
 
@@ -773,7 +776,7 @@ int c_get_workspace_count(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"get_workspace_count: %s", no_indata_expected_error);
+		luaL_error(lua, "get_workspace_count: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -800,7 +803,7 @@ int c_unmaximize_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"unmaximize: %s", no_indata_expected_error);
+		luaL_error(lua, "unmaximize: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -823,7 +826,7 @@ int c_maximize_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"maximize: %s", no_indata_expected_error);
+		luaL_error(lua, "maximize: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -845,7 +848,7 @@ int c_maximize_window_vertically(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"maximize_vertically: %s", no_indata_expected_error);
+		luaL_error(lua, "maximize_vertically: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -868,7 +871,7 @@ int c_maximize_window_horisontally(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"maximize_horisontally: %s", no_indata_expected_error);
+		luaL_error(lua, "maximize_horisontally: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -892,7 +895,7 @@ int c_pin_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"pin_window: %s", no_indata_expected_error);
+		luaL_error(lua, "pin_window: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -916,7 +919,7 @@ int c_unpin_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"unpin_window: %s", no_indata_expected_error);
+		luaL_error(lua, "unpin_window: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -939,7 +942,7 @@ int c_stick_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"stick_window: %s", no_indata_expected_error);
+		luaL_error(lua, "stick_window: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -962,7 +965,7 @@ int c_unstick_window(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"unstick_window: %s", no_indata_expected_error);
+		luaL_error(lua, "unstick_window: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -985,7 +988,7 @@ int c_get_window_geometry(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"get_window_geometry: %s", no_indata_expected_error);
+		luaL_error(lua, "get_window_geometry: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -1015,7 +1018,7 @@ int c_get_client_window_geometry(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"get_client_window_geometry: %s",no_indata_expected_error);
+		luaL_error(lua, "get_client_window_geometry: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -1091,12 +1094,12 @@ int c_set_skip_pager(lua_State *lua)
 
 	int value = lua_toboolean(lua, 1);
 
-	gboolean skip_pager=(gboolean)(value);
+	gboolean skip_pager = (gboolean)(value);
 
 	if (!devilspie2_emulate) {
 		WnckWindow *window = get_current_window();
 		if (window) {
-			wnck_window_set_skip_pager(window,skip_pager);
+			wnck_window_set_skip_pager(window, skip_pager);
 		}
 	}
 
@@ -1113,7 +1116,7 @@ int c_get_window_is_maximized(lua_State *lua)
 
 	if (top != 0) {
 		luaL_error(lua, "get_window_is__maximized: %s",
-			no_indata_expected_error);
+		           no_indata_expected_error);
 		return 0;
 	}
 
@@ -1138,7 +1141,7 @@ int c_get_window_is_maximized_vertically(lua_State *lua)
 
 	if (top != 0) {
 		luaL_error(lua, "get_window_is_horisontally_maximized: %s",
-			no_indata_expected_error);
+		           no_indata_expected_error);
 		return 0;
 	}
 
@@ -1164,7 +1167,7 @@ int c_get_window_is_maximized_horisontally(lua_State *lua)
 
 	if (top != 0) {
 		luaL_error(lua, "get_window_is_horisontally_maximized: %s",
-			no_indata_expected_error);
+		           no_indata_expected_error);
 		return 0;
 	}
 
@@ -1181,6 +1184,32 @@ int c_get_window_is_maximized_horisontally(lua_State *lua)
 }
 
 
+/**
+ *
+ */
+int c_get_window_is_pinned(lua_State *lua)
+{
+	int top = lua_gettop(lua);
+
+	if (top != 0) {
+		luaL_error(lua, "get_window_is_pinned: %s",
+		           no_indata_expected_error);
+		return 0;
+	}
+
+	WnckWindow *window = get_current_window();
+
+	gboolean is_pinned = FALSE;
+	if (window) {
+		is_pinned = wnck_window_is_pinned(window);
+	}
+
+	lua_pushboolean(lua, is_pinned);
+
+	return 1;
+}
+
+
 /**
  *
  */
@@ -1202,7 +1231,7 @@ int c_set_window_above(lua_State *lua)
 		}
 
 		int value = lua_toboolean(lua, 1);
-		set_above=(gboolean)(value);
+		set_above = (gboolean)(value);
 	}
 	else {
 		set_above = TRUE;
@@ -1212,10 +1241,10 @@ int c_set_window_above(lua_State *lua)
 	if (!devilspie2_emulate) {
 		Window xid = wnck_window_get_xid(window);
 		devilspie2_change_state(devilspie2_window_get_xscreen(xid),
-		                     xid,
-		                     set_above,
-		                     my_wnck_atom_get("_NET_WM_STATE_ABOVE"),
-		                     0);
+		                        xid,
+		                        set_above,
+		                        my_wnck_atom_get("_NET_WM_STATE_ABOVE"),
+		                        0);
 	}
 
 	return 0;
@@ -1243,7 +1272,7 @@ int c_set_window_below(lua_State *lua)
 		}
 
 		int value = lua_toboolean(lua, 1);
-		set_below=(gboolean)(value);
+		set_below = (gboolean)(value);
 	}
 	else {
 		set_below = TRUE;
@@ -1254,10 +1283,10 @@ int c_set_window_below(lua_State *lua)
 
 		Window xid = wnck_window_get_xid(window);
 		devilspie2_change_state(devilspie2_window_get_xscreen(xid),
-		                     xid,
-		                     set_below,
-		                     my_wnck_atom_get("_NET_WM_STATE_BELOW"),
-		                     0);
+		                        xid,
+		                        set_below,
+		                        my_wnck_atom_get("_NET_WM_STATE_BELOW"),
+		                        0);
 	}
 
 	return 0;
@@ -1272,7 +1301,7 @@ int c_get_window_type(lua_State *lua)
 	int top = lua_gettop(lua);
 
 	if (top != 0) {
-		luaL_error(lua,"get_window_type: %s", no_indata_expected_error);
+		luaL_error(lua, "get_window_type: %s", no_indata_expected_error);
 		return 0;
 	}
 
@@ -1334,7 +1363,7 @@ int c_get_class_instance_name(lua_State *lua)
 
 	if (top != 0) {
 		luaL_error(lua, "get_window_class_instance_name: %s",
-			no_indata_expected_error);
+		           no_indata_expected_error);
 		return 0;
 	}
 
@@ -1374,7 +1403,7 @@ int c_get_window_property(lua_State *lua)
 	int type = lua_type(lua, 1);
 
 	if (type != LUA_TSTRING) {
-		luaL_error(lua,"get_window_property: %s",string_expected_as_indata_error);
+		luaL_error(lua, "get_window_property: %s", string_expected_as_indata_error);
 		return 0;
 	}
 
@@ -1386,7 +1415,7 @@ int c_get_window_property(lua_State *lua)
 
 	if (window) {
 		result = my_wnck_get_string_property_latin1(wnck_window_get_xid(window),
-			my_wnck_atom_get(value));
+		         my_wnck_atom_get(value));
 	} else {
 		result = g_strdup_printf("NO RESULT");
 	}
@@ -1421,7 +1450,7 @@ int c_get_window_role(lua_State *lua)
 
 	if (window) {
 		result = my_wnck_get_string_property_latin1(wnck_window_get_xid(window),
-			my_wnck_atom_get("WM_WINDOW_ROLE"));
+		         my_wnck_atom_get("WM_WINDOW_ROLE"));
 	}
 
 	if (result) {
@@ -1485,12 +1514,12 @@ int c_get_window_class(lua_State *lua)
 
 #ifdef WNCK_MAJOR_VERSION
 #if WNCK_CHECK_VERSION(3,2,0)
-	gchar *class_name=(char*)wnck_class_group_get_id(class_group);
+		gchar *class_name = (char*)wnck_class_group_get_id(class_group);
 #else
-	gchar *class_name=(char*)wnck_class_group_get_res_class (class_group);
+		gchar *class_name = (char*)wnck_class_group_get_res_class (class_group);
 #endif
 #else
-	gchar *class_name = (char*)wnck_class_group_get_res_class (class_group);
+		gchar *class_name = (char*)wnck_class_group_get_res_class (class_group);
 #endif
 
 		result = g_strdup(class_name);
@@ -1516,7 +1545,7 @@ int c_set_window_fullscreen(lua_State *lua)
 
 	if (top != 1) {
 		luaL_error(lua, "set_window_fullscreen: %s",
-			one_indata_expected_error);
+		           one_indata_expected_error);
 		return 0;
 	}
 
@@ -1524,9 +1553,9 @@ int c_set_window_fullscreen(lua_State *lua)
 
 	int type = lua_type(lua, 1);
 
-	if (type!=LUA_TBOOLEAN) {
+	if (type != LUA_TBOOLEAN) {
 		luaL_error(lua, "set_window_fullscreen: %s",
-			boolean_expected_as_indata_error);
+		           boolean_expected_as_indata_error);
 		return 0;
 	}
 
@@ -1558,7 +1587,7 @@ int c_set_viewport(lua_State *lua)
 	}
 
 	int type = lua_type(lua, 1);
-	if (type!=LUA_TNUMBER) {
+	if (type != LUA_TNUMBER) {
 		luaL_error(lua, "set_viewport: %s", number_expected_as_indata_error);
 		return 0;
 	}
@@ -1596,7 +1625,7 @@ int c_set_viewport(lua_State *lua)
 	devilspie2_error_trap_push();
 	XMoveResizeWindow(gdk_x11_get_default_xdisplay(),
 	                  wnck_window_get_xid(window),
-	                  x,y,width,height);
+	                  x, y, width, height);
 
 	if (devilspie2_error_trap_pop()) {
 		g_printerr("set_viewport: %s", setting_viewport_failed_error);
@@ -1639,11 +1668,11 @@ int c_center(lua_State *lua)
 
 	workspace = wnck_screen_get_active_workspace(screen);
 
-	if (workspace==NULL) {
+	if (workspace == NULL) {
 		workspace = wnck_screen_get_workspace(screen,0);
 	}
 
-	if (workspace==NULL) {
+	if (workspace == NULL) {
 		g_printerr(_("Could not get workspace"));
 		lua_pushboolean(lua, FALSE);
 		return 1;
@@ -1859,7 +1888,7 @@ int c_xy(lua_State *lua)
 		int type2 = lua_type(lua, 2);
 
 		if ((type1 != LUA_TNUMBER) ||
-			 (type2 != LUA_TNUMBER)) {
+		        (type2 != LUA_TNUMBER)) {
 			luaL_error(lua, "xy: %s", two_indata_expected_error);
 			return 0;
 		}
@@ -1873,9 +1902,9 @@ int c_xy(lua_State *lua)
 
 			if (window) {
 				wnck_window_set_geometry(window,
-					WNCK_WINDOW_GRAVITY_CURRENT,
-					WNCK_WINDOW_CHANGE_X + WNCK_WINDOW_CHANGE_Y,
-					x, y, -1, -1);
+				                         WNCK_WINDOW_GRAVITY_CURRENT,
+				                         WNCK_WINDOW_CHANGE_X + WNCK_WINDOW_CHANGE_Y,
+				                         x, y, -1, -1);
 			}
 		}
 
@@ -1922,9 +1951,9 @@ int c_xywh(lua_State *lua)
 		int type4 = lua_type(lua, 4);
 
 		if ((type1 != LUA_TNUMBER) ||
-			 (type2 != LUA_TNUMBER) ||
-			 (type3 != LUA_TNUMBER) ||
-			 (type4 != LUA_TNUMBER)) {
+		        (type2 != LUA_TNUMBER) ||
+		        (type3 != LUA_TNUMBER) ||
+		        (type4 != LUA_TNUMBER)) {
 			luaL_error(lua, "xywh: %s", four_indata_expected_error);
 			return 0;
 		}
